# CFD constraints

## Boundary conditions

::: phydrax.constraints.ContinuousSymmetryVelocityBoundaryConstraint

---

::: phydrax.constraints.ContinuousNoPenetrationBoundaryConstraint

---

::: phydrax.constraints.ContinuousSlipWallBoundaryConstraint

---
---

::: phydrax.constraints.DiscreteNoPenetrationBoundaryConstraint

---

::: phydrax.constraints.DiscreteZeroNormalGradientVelocityBoundaryConstraint

## Integral / global constraints

::: phydrax.constraints.CFDBoundaryFlowRateConstraint

---

::: phydrax.constraints.CFDKineticEnergyFluxBoundaryConstraint

---

::: phydrax.constraints.AveragePressureBoundaryConstraint
